import {
  IonButton,
  IonButtons,
  IonContent,
  IonItem,
  IonLabel,
  IonList,
  IonModal,
  IonRadio,
  IonRadioGroup,
  IonTitle,
  IonToolbar,
} from '@ionic/react';
import React, { useRef } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { enterAnimation, leaveAnimation } from '../../lib/animation';
import { mapActions, MapState } from '../../store/map';
import { tileProviders } from './tile';

const TileServerChooserDialog: React.FC<{}> = () => {
  const tileProvider = useSelector(
    (state: { map: MapState }) => state.map.scope.tileProvider
  ) as keyof typeof tileProviders;

  const dispatch = useDispatch();

  const modal = useRef<HTMLIonModalElement>(null);

  const dismiss = () => {
    modal.current?.dismiss();
  };

  const changeHandler = (event: any) => {
    dispatch(mapActions.setTileProvider(event.detail.value));
    dismiss();
  };


  return (
    <IonModal
      ref={modal}
      trigger='open-TileServerChooser'
      enterAnimation={enterAnimation}
      leaveAnimation={leaveAnimation}
    >
      <IonToolbar>
        <IonTitle>Choose your map</IonTitle>
        <IonButtons slot='end'>
          <IonButton onClick={() => dismiss()}>Close</IonButton>
        </IonButtons>
      </IonToolbar>
      <IonContent>
        <IonList>
          <IonRadioGroup value={tileProvider} onIonChange={changeHandler}>
            {Object.keys(tileProviders).map((provider) => {
              return (
                <IonItem key={provider}>
                  <IonLabel> {tileProviders[provider].name}</IonLabel>
                  <IonRadio slot='start' value={provider} />
                </IonItem>
              );
            })}
          </IonRadioGroup>
        </IonList>
      </IonContent>
    </IonModal>
  );
};

export default TileServerChooserDialog;
